@@ -48,7 +48,7 @@ class NxPyDocs():
                 self.command = single_command
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                pp.pprint(json.dumps(parsed_json))
+                pp.pprint(json.dumps(parsed_json,indent=4, sort_keys=True))
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
@@ -58,7 +58,7 @@ class NxPyDocs():
             if self.command in self.supported_templates:
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                pp.pprint(json.dumps(parsed_json))
+                pp.pprint(json.dumps(parsed_json,indent=4, sort_keys=True))
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
@@ -86,14 +86,15 @@ class NxPyDocs():
 
     def json_file(self, parsed_json):
         with open(' %s.json' % self.command, 'w') as f:
-            f.write(json.dumps(parsed_json))
+            f.write(json.dumps(parsed_json,indent=4, sort_keys=True))
         click.secho("JSON file created at %s / %s.json" % (sys.path[0],self.command),
         fg='green')
 
     def yaml_file(self, parsed_json):
-        clean_yaml = yaml.dump(json.loads(json.dumps(parsed_json)), default_flow_style=False)
+        clean_yaml = yaml.dump(json.loads(json.dumps(parsed_json,indent=4, sort_keys=True)), default_flow_style=False)
         with open(' %s.yaml' % self.command, 'w') as f:
             f.write(clean_yaml)
+        print(clean_yaml)
         click.secho("YAML file created at %s / %s.yaml" % (sys.path[0],self.command),
         fg='green')
 
@@ -105,6 +106,7 @@ class NxPyDocs():
             data_to_template=json.loads(parsed_json))
         with open('%s.html' % self.command, 'w') as f:
             f.write(html_output)
+        print(html_output)
         click.secho("HTML file created at %s / %s.html" % (sys.path[0],self.command),
             fg='green')
 
@@ -116,6 +118,7 @@ class NxPyDocs():
             data_to_template=json.loads(parsed_json))
         with open('%s.md' % self.command, 'w') as f:
             f.write(markdown_output)
+        print(markdown_output)
         click.secho("Markdown file created at %s / %s.md" % (sys.path[0],self.command),
             fg='green')
 
@@ -128,6 +131,7 @@ class NxPyDocs():
             hostname=self.hostname)
         with open('%s.csv' % self.command, 'w') as f:
             f.write(csv_output)
+        print(csv_output)
         click.secho("CSV file created at %s / %s.csv" % (sys.path[0],self.command),
             fg='green')
 
@@ -140,6 +144,7 @@ class NxPyDocs():
             hostname=self.hostname)
         with open('%s mindmap.md' % self.command, 'w') as f:
             f.write(mindmap_output)
+        print(mindmap_output)
         click.secho(
             "Mindmap file created at %s / %s.md" % (sys.path[0],self.command),
             fg='green')
